@@ -16,5 +16,7 @@ if (prefs.player === 1) {
     style.push("LeanBackPlayer/css.player/leanbackPlayer.default.css");
 }
 */
+exports.type = "site";
+exports.name = "common";
 exports.inject = inject;
 exports.style = style;
\ No newline at end of file
